==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-admin/lxqt-admin-user/lxqt-admin-user.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../../../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="37"/>
        <source>Group ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="44"/>
        <source>Users belong to this group:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="86"/>
        <location filename="../../../groupdialog.cpp" line="95"/>
        <location filename="../../../groupdialog.cpp" line="100"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="86"/>
        <source>The group ID is in use.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="95"/>
        <source>The group name cannot be empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="100"/>
        <source>The group name is in use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="31"/>
        <source>&amp;Users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="50"/>
        <source>Login Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="55"/>
        <source>User ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="60"/>
        <source>Full Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="65"/>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="70"/>
        <source>Home Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="81"/>
        <source>Show system users (for advanced users only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="89"/>
        <source>&amp;Groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="102"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="107"/>
        <source>Group ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="120"/>
        <source>toolBar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="147"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="150"/>
        <source>Add new users or groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="160"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="163"/>
        <source>Delete selected item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="173"/>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="176"/>
        <source>edit properties of the selected item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="186"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="189"/>
        <source>Refresh the lists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="145"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="191"/>
        <location filename="../../../mainwindow.cpp" line="204"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="191"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="204"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../../../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="24"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="33"/>
        <source>Full name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="43"/>
        <source>Login name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="53"/>
        <source>Set password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="77"/>
        <source>User ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="84"/>
        <source>Main group:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="99"/>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="105"/>
        <source>Login shell:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="122"/>
        <source>Home directory:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="67"/>
        <source>Change password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="128"/>
        <location filename="../../../userdialog.cpp" line="141"/>
        <location filename="../../../userdialog.cpp" line="146"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="128"/>
        <source>The user ID is in use.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="141"/>
        <source>The user name cannot be empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="146"/>
        <source>The user name is in use.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="162"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="162"/>
        <source>Are you sure you want to use an &quot;empty password&quot; for the user?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-admin/lxqt-admin-user/lxqt-admin-user.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../../../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="59"/>
        <source>Login Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="64"/>
        <source>User ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="69"/>
        <source>Full Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="74"/>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="79"/>
        <source>Home Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="111"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="116"/>
        <source>Group ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="121"/>
        <source>Members</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="134"/>
        <source>toolBar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="161"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="164"/>
        <source>Add new users or groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="173"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="176"/>
        <source>Delete selected item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="185"/>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="188"/>
        <source>edit properties of the selected item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="197"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="200"/>
        <source>Refresh the lists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="209"/>
        <source>Change Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="212"/>
        <source>Change password for the selected user or group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="174"/>
        <location filename="../../../mainwindow.cpp" line="186"/>
        <location filename="../../../mainwindow.cpp" line="207"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="174"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="186"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="197"/>
        <source>Input the new password for %1:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="207"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../../../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="24"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="117"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="117"/>
        <source>The user name cannot be empty.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../../../usermanager.cpp" line="224"/>
        <source>lxqt-admin-user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../usermanager.cpp" line="225"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
